OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Konsoli",
    "Dashboard app" : "Konsolisovellus",
    "Customize" : "Mukauta",
    "Change background image" : "Vaihda taustakuva",
    "Weather service" : "Sääpalvelu",
    "Weather data from Met.no" : "Säätiedot tarjoaa Met.no",
    "Weather" : "Sää",
    "Status" : "Tila",
    "Good evening, {name}" : "Hyvää iltaa, {name}",
    "Good evening" : "Hyvää iltaa",
    "Good afternoon, {name}" : "Hyvää iltapäivää, {name}",
    "Good afternoon" : "Hyvää iltapäivää",
    "Good morning, {name}" : "Hyvää huomenta, {name}",
    "Good morning" : "Hyvää huomenta",
    "Good night, {name}" : "Hyvää yötä, {name}",
    "Good night" : "Hyvää yötä",
    "Pick from files" : "Valitse tiedostoista",
    "Default images" : "Oletuskuvat"
},
"nplurals=2; plural=(n != 1);");
